Package: tidyfit
Type: Package
Title: Regularized Linear Modeling with Tidy Data
Date: 2024-09-30
Version: 0.7.2
Author: Johann Pfitzinger [aut, cre]
Authors@R: person(given = "Johann", family = "Pfitzinger", role = c("aut", "cre"), email = "johann.pfitzinger@gmail.com")
Maintainer: Johann Pfitzinger <johann.pfitzinger@gmail.com>
Description: An extension to the 'R' tidy data environment for automated machine learning. The package allows fitting and cross validation of linear regression and classification algorithms on grouped data. 
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
URL: https://tidyfit.residualmetrics.com,
        https://github.com/jpfitzinger/tidyfit
Depends: R (>= 3.5)
Imports: broom, crayon, dials, dplyr, furrr, generics, magrittr, MASS,
        methods, progressr, purrr, rlang, rsample, stats, tibble,
        tidyr, utils, vctrs, yardstick
Suggests: arm, bestglm, BMS, BoomSpikeSlab, CORElearn, e1071, gaselect,
        gets, gglasso, ggplot2, glmnet, hfr, iml, kableExtra, knitr,
        lme4, lmtest, lubridate, markdown, mboost, monomvn, mRMRe,
        MSwM, nnet, pls, quantreg, quantregForest, randomForest,
        sandwich, sensitivity, shrinkTVP, stringr, rmarkdown, testthat
        (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-10-03 13:20:19 UTC; johann
Repository: CRAN
Date/Publication: 2024-10-03 13:40:02 UTC
Built: R 4.4.1; ; 2024-11-06 04:09:37 UTC; unix
